from typing import Optional

import socketio

from server.game.lobby import LobbyManager
from server.model.hand import Hand
from server.model.players import Player, Announce

sio = socketio.AsyncServer(
    async_mode='asgi',
    logger=True,
    cors_allowed_origins="*"  # FIXME: CSRF Vulnerability
)
lobby = LobbyManager(sio)


class ClientPlayer(Player):
    def __init__(self, lobby: LobbyManager):
        super().__init__()
        self.lobby = lobby

    async def announce(self, current_bet: Optional[Hand]) -> Announce:
        return lobby.last_announces[self]


@sio.event
async def connect(sid, environ):
    print("[WS] Connect ", sid, environ)
    player = ClientPlayer(lobby)
    await lobby.add_player(player)


@sio.event
async def message(sid, data):
    print("[WS] Message ", data)
    await sio.emit('messageChannel', "OK", room=sid)


@sio.on("pingServer")
async def ping_server(sid, data):
    print("[WS] Ping received:", data)
    await sio.emit('messageChannel', "PONG")


@sio.event
def disconnect(sid):
    print('[WS] Disconnect ', sid)
